unit uController.Artistas;

interface

uses
  MVCFramework, MVCFramework.Commons, MVCFramework.Serializer.Commons,
  MVCFramework.ActiveRecord, MVCFramework.SQLGenerators.Sqlite;

type

  [MVCPath('/api')]
  TControllerArtistas = class(TMVCController) 
  public
    [MVCPath]
    [MVCHTTPMethod([httpGET])]
    procedure Index;

    [MVCPath('/reversedstrings/($Value)')]
    [MVCHTTPMethod([httpGET])]
    procedure GetReversedString(const Value: String);
  protected
    procedure OnBeforeAction(Context: TWebContext; const AActionName: string; var Handled: Boolean); override;
    procedure OnAfterAction(Context: TWebContext; const AActionName: string); override;

  public
    //Sample CRUD Actions for a "Customer" entity
    [MVCPath('/artistas')]
    [MVCHTTPMethod([httpGET])]
    procedure GetArtistas;

    [MVCPath('/artistas/($id)')]
    [MVCHTTPMethod([httpGET])]
    procedure GetArtista(id: Integer);

    [MVCPath('/artistas')]
    [MVCHTTPMethod([httpPOST])]
    procedure CreateArtista;

    [MVCPath('/artistas/($id)')]
    [MVCHTTPMethod([httpPUT])]
    procedure UpdateArtista(id: Integer);

    [MVCPath('/artistas/($id)')]
    [MVCHTTPMethod([httpDELETE])]
    procedure DeleteArtista(id: Integer);

    constructor Create; override;

  end;

implementation

uses
  uModel.Artistas,
  uDMConexion,
  System.SysUtils, MVCFramework.Logger, System.StrUtils, System.Generics.collections;

procedure TControllerArtistas.Index;
begin
  //use Context property to access to the HTTP request and response 
  Render('Hello DelphiMVCFramework World');
end;

procedure TControllerArtistas.GetReversedString(const Value: String);
begin
  Render(System.StrUtils.ReverseString(Value.Trim));
end;

procedure TControllerArtistas.OnAfterAction(Context: TWebContext; const AActionName: string); 
begin
  { Executed after each action }
  inherited;
end;

procedure TControllerArtistas.OnBeforeAction(Context: TWebContext; const AActionName: string; var Handled: Boolean);
begin
  { Executed before each action
    if handled is true (or an exception is raised) the actual
    action will not be called }
  inherited;
end;

//Sample CRUD Actions for a "Customer" entity
procedure TControllerArtistas.GetArtistas;
var
  lartistas:TObjectList<TArtista>;
begin
  // lartistas := TMVCActiveRecord.All<TArtista>;
  lartistas := TMVCActiveRecord.Select<TArtista>('SELECT * FROM ARTISTS', []);
  Render<TArtista>(lartistas);
end;

procedure TControllerArtistas.GetArtista(id: Integer);
var
  artista:TArtista;
begin
  artista := TMVCActiveRecord.GetByPK<TArtista>(id);
  Render(artista);
end;

constructor TControllerArtistas.Create;
begin
  inherited;
  ActiveRecordConnectionsRegistry.AddDefaultConnection(dmConexion.TestdbConnection);
end;

procedure TControllerArtistas.CreateArtista;
var
  artista:TArtista;
begin
  artista := Context.Request.BodyAs<TArtista>;
  artista.Insert;
//  ContentType := 'text/html';
  // Render(Format('Se ha insertado correctamente el artista [%s]',[artista.Name]));
  Render(artista);
end;

procedure TControllerArtistas.UpdateArtista(id: Integer);
var
  artista:TArtista;
begin
  artista := Context.Request.BodyAs<TArtista>;
  artista.Artistid := id;
  artista.Update;
  ContentType := 'text/html';
  Render('Se ha actualizado el artista correctamente');
end;

procedure TControllerArtistas.DeleteArtista(id: Integer);
var
  artista:TArtista;
begin
  try
    artista := TMVCActiveRecord.GetByPK<TArtista>(id);
  except
    on E:EMVCActiveRecordNotFound do begin
      ResponseStatus(401, 'Registro no encontrado');
      exit;
    end;
  end;
  artista.Delete;
  Render('El artista se ha borrado correctamente');
end;



end.
